@@ -14,9 +14,10 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.1.22'
+__version__ = '0.2.0'
 
-__all__ = ['ANY_ARGUMENTS',
+__all__ = ['ANY_ARGUMENT',
+           'ANY_ARGUMENTS',
            'AT_LEAST_ONCE',
            'NEVER',
            'UnitTests',
